# Başla!

Rapunzele hoşgeldin. Rapunzel Python ve R için geliştirilmiş modern bir platformdur. Birkaç işe yarar klavye kısayolu:


## Proje klasörleri ve dosyaları ile çalışmak

- [`Ctrl+Shift+O`: Proje klasörünü aç](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Proje klasöründen bir dosya aç](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Boş dosya oluştur](opensesame://event.ide_new_file)


## İşleri daha kısa sürede yapmak için

- [`Ctrl+Shift+P`: Command paletini aktive et](opensesame://event.command_palette_activate)
- `Ctrl+R`: Bir fonksiyona ya da class a git


## Kod çalıştırmak

- `F5`: Projeyi ya da dosyayı çalıştır
- `F9`: Seçili alanı hücreyi ya da üzerinde olunan satırı çalıştır